@@ -33,9 +33,9 @@ ncdc_locs_cats <- function(datasetid=NULL, locationcategoryid=NULL,
   limit=25, offset=NULL, token=NULL, ...)
 {
   token <- check_key(token)
-  url <- 'http://www.ncdc.noaa.gov/cdo-web/api/v2/locationcategories'
-  if(!is.null(locationcategoryid))
-    url <- paste(url, "/", locationcategoryid, sep="")
+  url <- paste0(ncdc_base(), "locationcategories")
+  if (!is.null(locationcategoryid))
+    url <- paste(url, "/", locationcategoryid, sep = "")
   args <- noaa_compact(list(locationcategoryid=locationcategoryid,
     startdate=startdate, enddate=enddate,token=token,sortfield=sortfield,
     sortorder=sortorder,limit=limit,offset=offset))
@@ -45,20 +45,19 @@ ncdc_locs_cats <- function(datasetid=NULL, locationcategoryid=NULL,
   args <- c(args, datasetid)
   args <- as.list(unlist(args))
   if (length(args) == 0) args <- NULL
-  temp <- GET(url, query=args, add_headers("token" = token), ...)
+  temp <- GET(url, query = args, add_headers("token" = token), ...)
   tt <- check_response(temp)
-  if(inherits(tt, "character")){
-    all <- list(meta=NULL, data=NULL)
+  if (inherits(tt, "character")) {
+    all <- list(meta = NULL, data = NULL)
   } else {
-    if(!is.null(locationcategoryid)){
-      dat <- data.frame(tt,stringsAsFactors=FALSE)
-      all <- list(meta=NULL, data=dat)
-    } else
-    {
-      dat <- dplyr::bind_rows(lapply(tt$results, function(x) data.frame(x,stringsAsFactors=FALSE)))
+    if (!is.null(locationcategoryid)) {
+      dat <- data.frame(tt, stringsAsFactors = FALSE)
+      all <- list(meta = NULL, data = dat)
+    } else {
+      dat <- dplyr::bind_rows(lapply(tt$results, function(x) data.frame(x,stringsAsFactors = FALSE)))
       meta <- tt$metadata$resultset
-      atts <- list(totalCount=meta$count, pageCount=meta$limit, offset=meta$offset)
-      all <- list(meta=atts, data=dat)
+      atts <- list(totalCount = meta$count, pageCount = meta$limit, offset = meta$offset)
+      all <- list(meta = atts, data = dat)
     }
   }
   class(all) <- "ncdc_locs_cats"
